@@ -479,6 +479,9 @@ where
                     punct!(self, span, "@");
                     self.wr.write_raw(Some(n.span), &raw)?;
                 }
+                Token::Delim { value } => {
+                    self.wr.write_raw_char(Some(n.span), *value)?;
+                }
                 Token::LParen => {
                     punct!(self, span, "(");
                 }
